@@ -44,6 +44,9 @@
 #include "contacts/ContactsImporterPluginsManager.hpp"
 #include "contacts/ContactsImporterListModel.hpp"
 #include "contacts/ContactsImporterListProxyModel.hpp"
+#include "content/ContentListModel.hpp"
+#include "content/ContentModel.hpp"
+#include "content/ContentProxyModel.hpp"
 #include "core/CoreHandlers.hpp"
 #include "core/CoreManager.hpp"
 #include "file/FileDownloader.hpp"
@@ -63,6 +66,8 @@
 #include "participant-imdn/ParticipantImdnStateListModel.hpp"
 #include "participant-imdn/ParticipantImdnStateProxyModel.hpp"
 #include "presence/OwnPresenceModel.hpp"
+#include "recorder/RecorderModel.hpp"
+#include "recorder/RecorderManager.hpp"
 #include "settings/AccountSettingsModel.hpp"
 #include "settings/SettingsModel.hpp"
 #include "search/SearchResultModel.hpp"
