@@ -215,7 +215,11 @@ bool AssistantModel::addOtherSipAccount (const QVariantMap &map) {
     shared_ptr<linphone::Address> address = factory->createAddress(
       Utils::appStringToCoreString(QStringLiteral("sip:%1").arg(domain))
     );
-
+	if(!address) {
+		qWarning() << QStringLiteral("Unable to create address from domain `%1`.")
+			.arg(domain);
+		return false;
+	}
     const QString &transport(map["transport"].toString());
     if (!transport.isEmpty())
       address->setTransport(Utils::stringToTransportType(transport));
@@ -410,11 +414,11 @@ void AssistantModel::setConfigFilename (const QString &configFilename) {
 
   QString configPath = Utils::coreStringToAppString(Paths::getAssistantConfigDirPath()) + configFilename;
   qInfo() << QStringLiteral("Set config on assistant: `%1`.").arg(configPath);
-
-  CoreManager::getInstance()->getCore()->getConfig()->loadFromXmlFile(
+  auto core = CoreManager::getInstance()->getCore();
+  core->getConfig()->loadFromXmlFile(
     Utils::appStringToCoreString(configPath)
   );
-
+  core->enableLimeX3Dh(core->getLimeX3DhServerUrl() != "");
   emit configFilenameChanged(configFilename);
 }
 
