@@ -83,7 +83,7 @@ CallModel::CallModel (shared_ptr<linphone::Call> call){
 	mMagicSearch->addListener(mSearch);
 	
 	mRemoteAddress = mCall->getRemoteAddress()->clone();
-	mMagicSearch->getContactListFromFilterAsync(mRemoteAddress->getUsername(),mRemoteAddress->getDomain());
+	mMagicSearch->getContactsListAsync(mRemoteAddress->getUsername(),mRemoteAddress->getDomain(), (int)linphone::MagicSearchSource::LdapServers | (int)linphone::MagicSearchSource::Friends, linphone::MagicSearchAggregation::Friend);
 }
 
 CallModel::~CallModel () {
@@ -111,8 +111,8 @@ QString CallModel::getFullLocalAddress () const {
 // -----------------------------------------------------------------------------
 
 ContactModel *CallModel::getContactModel() const{
-	auto contact = CoreManager::getInstance()->getContactsListModel()->findContactModelFromSipAddress(Utils::coreStringToAppString(mCall->getRemoteAddress()->asString()));
-	return contact;
+	QString cleanedAddress = Utils::cleanSipAddress(Utils::coreStringToAppString(mCall->getRemoteAddress()->asString()));
+	return CoreManager::getInstance()->getContactsListModel()->findContactModelFromSipAddress(cleanedAddress);
 }
 
 ChatRoomModel * CallModel::getChatRoomModel() const{
@@ -625,6 +625,10 @@ void CallModel::setPausedByUser (bool status) {
 }
 
 // -----------------------------------------------------------------------------
+bool CallModel::getRemoteVideoEnabled () const {
+	shared_ptr<const linphone::CallParams> params = mCall->getRemoteParams();
+	return params && params->videoEnabled();
+}
 
 bool CallModel::getVideoEnabled () const {
 	shared_ptr<const linphone::CallParams> params = mCall->getCurrentParams();
@@ -703,10 +707,11 @@ void CallModel::toggleSpeakerMute(){
 // -----------------------------------------------------------------------------
 
 // Set remote display name when a search has been done
+// Local Friend > LDAP friend > Address > others
 void CallModel::searchReceived(std::list<std::shared_ptr<linphone::SearchResult>> results){
 	bool found = false;
 	for(auto it = results.begin() ; it != results.end() && !found ; ++it){
-		if((*it)->getFriend()){
+		if((*it)->getFriend()){// Local Friend
 			if((*it)->getFriend()->getAddress()->weakEqual(mRemoteAddress)){
 				setRemoteDisplayName((*it)->getFriend()->getName());
 				found = true;
@@ -714,9 +719,16 @@ void CallModel::searchReceived(std::list<std::shared_ptr<linphone::SearchResult>
 		}else{
 			if((*it)->getAddress()->weakEqual(mRemoteAddress)){
 				std::string newDisplayName = (*it)->getAddress()->getDisplayName();
-				if(!newDisplayName.empty())// Override only if there is one
-					setRemoteDisplayName(newDisplayName);
-				found = true;
+				if(!newDisplayName.empty()){
+				// LDAP friend
+					if( ((*it)->getSourceFlags() & (int) linphone::MagicSearchSource::LdapServers) == (int) linphone::MagicSearchSource::LdapServers){
+						setRemoteDisplayName(newDisplayName);
+						found = true;
+					}else if( Utils::coreStringToAppString(mRemoteAddress->getDisplayName()).isEmpty()){
+						setRemoteDisplayName(newDisplayName);	
+						found = true;
+					}
+				}
 			}
 		}
 	}
@@ -941,11 +953,10 @@ QString CallModel::generateSavedFilename () const {
 
 QString CallModel::generateSavedFilename (const QString &from, const QString &to) {
 	auto escape = [](const QString &str) {
-		constexpr char ReservedCharacters[] = "<>:\"/\\|\\?\\*";
+		constexpr char ReservedCharacters[] = "[<|>|:|\"|/|\\\\|\\?|\\*|\\+|\\|]+";
 		static QRegularExpression regexp(ReservedCharacters);
 		return QString(str).replace(regexp, "");
 	};
-	
 	return QStringLiteral("%1_%2_%3")
 			.arg(QDateTime::currentDateTime().toString("yyyy-MM-dd_hh-mm-ss"))
 			.arg(escape(from))
