@@ -37,6 +37,8 @@
 #include "app/App.hpp"
 #include "app/paths/Paths.hpp"
 #include "app/providers/ThumbnailProvider.hpp"
+#include "components/calls/CallsListModel.hpp"
+#include "components/chat/ChatModel.hpp"
 #include "components/chat-events/ChatCallModel.hpp"
 #include "components/chat-events/ChatEvent.hpp"
 #include "components/chat-events/ChatMessageModel.hpp"
@@ -44,6 +46,8 @@
 #include "components/contact/ContactModel.hpp"
 #include "components/contact/VcardModel.hpp"
 #include "components/contacts/ContactsListModel.hpp"
+#include "components/content/ContentListModel.hpp"
+#include "components/content/ContentModel.hpp"
 #include "components/core/CoreHandlers.hpp"
 #include "components/core/CoreManager.hpp"
 #include "components/notifier/Notifier.hpp"
@@ -52,6 +56,8 @@
 #include "components/participant/ParticipantModel.hpp"
 #include "components/participant/ParticipantListModel.hpp"
 #include "components/presence/Presence.hpp"
+#include "components/recorder/RecorderManager.hpp"
+#include "components/recorder/RecorderModel.hpp"
 #include "components/timeline/TimelineModel.hpp"
 #include "components/timeline/TimelineListModel.hpp"
 #include "components/core/event-count-notifier/AbstractEventCountNotifier.hpp"
@@ -187,34 +193,22 @@ std::shared_ptr<ChatRoomModel> ChatRoomModel::create(std::shared_ptr<linphone::C
 ChatRoomModel::ChatRoomModel (std::shared_ptr<linphone::ChatRoom> chatRoom, QObject * parent) : QAbstractListModel(parent){
 	App::getInstance()->getEngine()->setObjectOwnership(this, QQmlEngine::CppOwnership);// Avoid QML to destroy it when passing by Q_INVOKABLE
 	CoreManager *coreManager = CoreManager::getInstance();
-	
 	mCoreHandlers = coreManager->getHandlers();
 	
 	mChatRoom = chatRoom;
 	mChatRoomModelListener = std::make_shared<ChatRoomModelListener>(this, parent);
-	mChatRoom->addListener(mChatRoomModelListener);
-	
-// Get Max updatetime from chat room and last call event	
-	
-	auto callHistory = CoreManager::getInstance()->getCore()->getCallHistory(mChatRoom->getPeerAddress(), mChatRoom->getLocalAddress());
-	if(callHistory.size() > 0){
-		auto callDate = callHistory.front()->getStartDate();
-		if( callHistory.front()->getStatus() == linphone::Call::Status::Success )
-			callDate += callHistory.front()->getDuration();
-		setLastUpdateTime(QDateTime::fromMSecsSinceEpoch(max(mChatRoom->getLastUpdateTime(), callDate )*1000));
-	}else
-		setLastUpdateTime(QDateTime::fromMSecsSinceEpoch(mChatRoom->getLastUpdateTime()*1000));
-	
-	
-	setUnreadMessagesCount(mChatRoom->getUnreadMessagesCount());
-	setMissedCallsCount(0);
+	mChatRoom->addListener(mChatRoomModelListener);	
 	
 	// Get messages.
 	mEntries.clear();
 	
+	setUnreadMessagesCount(mChatRoom->getUnreadMessagesCount());
+	setMissedCallsCount(0);
+	
 	QElapsedTimer timer;
 	timer.start();
 	CoreHandlers *coreHandlers = mCoreHandlers.get();
+	QObject::connect(this, &ChatRoomModel::messageSent, this, &ChatRoomModel::resetMessageCount);
 	//QObject::connect(coreHandlers, &CoreHandlers::messageReceived, this, &ChatRoomModel::handleMessageReceived);
 	QObject::connect(coreHandlers, &CoreHandlers::callCreated, this, &ChatRoomModel::handleCallCreated);
 	QObject::connect(coreHandlers, &CoreHandlers::callStateChanged, this, &ChatRoomModel::handleCallStateChanged);
@@ -242,8 +236,10 @@ ChatRoomModel::ChatRoomModel (std::shared_ptr<linphone::ChatRoom> chatRoom, QObj
 				connect(contact, &ContactModel::contactUpdated, this, &ChatRoomModel::fullPeerAddressChanged);
 			}
 		}
+		
 	}else
 		mParticipantListModel = nullptr;
+	
 }
 
 ChatRoomModel::~ChatRoomModel () {
@@ -296,7 +292,7 @@ QVariant ChatRoomModel::data (const QModelIndex &index, int role) const {
 				return QVariant();
 		}
 		case Roles::SectionDate:
-			return QVariant::fromValue(mEntries[row]->mTimestamp.date());
+			return QVariant::fromValue(mEntries[row]->getTimestamp().date());
 	}
 	
 	return QVariant();
@@ -334,15 +330,18 @@ void ChatRoomModel::removeAllEntries () {
 			   .arg(getPeerAddress()).arg(getLocalAddress());
 	auto core = CoreManager::getInstance()->getCore();
 	bool standardChatEnabled = CoreManager::getInstance()->getSettingsModel()->getStandardChatEnabled();
-	beginResetModel();	
+	beginResetModel();
 	mEntries.clear();
 	mChatRoom->deleteHistory();
 	if( isOneToOne() && // Remove calls only if chat room is one-one and not secure (if available)
 		( !standardChatEnabled || !isSecure())
 		) {
-		auto callLogs = core->getCallHistory(mChatRoom->getPeerAddress(), mChatRoom->getLocalAddress());
+		auto callLogs = CallsListModel::getCallHistory(getParticipantAddress(), Utils::coreStringToAppString(mChatRoom->getLocalAddress()->asStringUriOnly()));
+		bool haveLogs = callLogs.size() > 0;
 		for(auto callLog : callLogs)
 			core->removeCallLog(callLog);
+		if(haveLogs)
+			emit CoreManager::getInstance()->callLogsCountChanged();
 	}
 	endResetModel();
 	emit allEntriesRemoved(mSelf.lock());
@@ -367,7 +366,7 @@ void ChatRoomModel::emitFullPeerAddressChanged(){
 //--------------------------------------------------------------------------------------------
 
 QString ChatRoomModel::getPeerAddress () const {
-	return mChatRoom ? Utils::coreStringToAppString(mChatRoom->getPeerAddress()->asStringUriOnly()) : "";
+	return mChatRoom && mChatRoom->getPeerAddress() ? Utils::coreStringToAppString(mChatRoom->getPeerAddress()->asStringUriOnly()) : "";
 }
 
 QString ChatRoomModel::getLocalAddress () const {
@@ -429,7 +428,15 @@ QString ChatRoomModel::getUsername () const {
 	username = Utils::getDisplayName(mChatRoom->getPeerAddress());
 	if(username != "")
 		return username;
-	return Utils::coreStringToAppString(mChatRoom->getPeerAddress()->asStringUriOnly());
+	auto addr = mChatRoom->getPeerAddress();
+	if( addr)
+		return Utils::coreStringToAppString(addr->asStringUriOnly());
+	else {
+		qWarning() << "ChatRoom has no peer address or address is invalid : Subject=" << mChatRoom->getSubject().c_str() 
+			<< ", created at " << QDateTime::fromSecsSinceEpoch(mChatRoom->getCreationTime())
+			<< " (" << mChatRoom.get() << ")";
+		return "";
+	}
 }
 
 QString ChatRoomModel::getAvatar () const {
@@ -463,8 +470,8 @@ int ChatRoomModel::getState() const {
 	return mChatRoom ? (int)mChatRoom->getState() : 0;	
 }
 
-bool ChatRoomModel::hasBeenLeft() const{
-	return mChatRoom && mChatRoom->hasBeenLeft();	
+bool ChatRoomModel::isReadOnly() const{
+	return mChatRoom && mChatRoom->isReadOnly();	
 }
 
 bool ChatRoomModel::isEphemeralEnabled() const{
@@ -483,6 +490,10 @@ bool ChatRoomModel::haveEncryption() const{
 	return mChatRoom && mChatRoom->getCurrentParams()->getEncryptionBackend() != linphone::ChatRoomEncryptionBackend::None;
 }
 
+bool ChatRoomModel::markAsReadEnabled() const{
+	return mMarkAsReadEnabled;
+}
+
 bool ChatRoomModel::isSecure() const{
 	return mChatRoom && (mChatRoom->getSecurityLevel() == linphone::ChatRoomSecurityLevel::Encrypted
 			|| mChatRoom->getSecurityLevel() == linphone::ChatRoomSecurityLevel::Safe);
@@ -515,11 +526,18 @@ bool ChatRoomModel::isCurrentProxy() const{
 bool ChatRoomModel::canHandleParticipants() const{
 	return mChatRoom->canHandleParticipants();
 }
-/*
+
 bool ChatRoomModel::getIsRemoteComposing () const {
-	return mIsRemoteComposing;
+	return mComposers.size() > 0;
+}
+
+bool ChatRoomModel::isEntriesLoading() const{
+	return mEntriesLoading;
+}
+
+bool ChatRoomModel::isBasic() const{
+	return mChatRoom && mChatRoom->hasCapability((int)linphone::ChatRoomCapabilities::Basic);
 }
-*/
 
 std::shared_ptr<linphone::ChatRoom> ChatRoomModel::getChatRoom(){
 	return mChatRoom;
@@ -529,6 +547,40 @@ QList<QString> ChatRoomModel::getComposers(){
 	return mComposers.values();
 }
 
+QString ChatRoomModel::getParticipantAddress(){
+	if(!isSecure()){
+		auto peerAddress = mChatRoom->getPeerAddress();
+		if( peerAddress)
+			return Utils::coreStringToAppString(peerAddress->asString());
+		else if(isConference()){
+			auto conferenceAddress = mChatRoom->getConferenceAddress();
+			if( conferenceAddress)
+				return Utils::coreStringToAppString(conferenceAddress->asString());
+			else{
+				qWarning() << "ConferenceAddress is NULL when requesting it from not secure and conference ChatRoomModel. Subject=" << mChatRoom->getSubject().c_str() 
+					<< ", created at " << QDateTime::fromSecsSinceEpoch(mChatRoom->getCreationTime())
+					<< " (" << mChatRoom.get() << ")";
+				return "";
+			}
+		}else {
+			qWarning() << "PeerAddress is NULL when requesting it from not secure ChatRoomModel. Subject=" << mChatRoom->getSubject().c_str()
+				<< ", created at " << QDateTime::fromSecsSinceEpoch(mChatRoom->getCreationTime())
+				<< " (" << mChatRoom.get() << ")";
+			return "";
+		}
+	}else{
+		auto participants = getParticipants();
+		if(participants->getCount() > 1)
+			return participants->getAt(1)->getSipAddress();
+		else
+			return "";
+	}	
+}
+
+int ChatRoomModel::getAllUnreadCount(){
+	return mUnreadMessagesCount + mMissedCallsCount;
+}
+
 //------------------------------------------------------------------------------------------------
 
 void ChatRoomModel::setSubject(QString& subject){
@@ -546,16 +598,19 @@ void ChatRoomModel::setLastUpdateTime(const QDateTime& lastUpdateDate) {
 }
 
 void ChatRoomModel::updateLastUpdateTime(){
-	QDateTime lastDateTime = QDateTime::fromMSecsSinceEpoch(mChatRoom->getLastUpdateTime()*1000);
-	QDateTime lastCallTime = lastDateTime;
-	for(auto e : mEntries){
-		if(e->mType == CallEntry && e->mTimestamp > lastCallTime)
-			lastCallTime = e->mTimestamp;
-	}	
-	setLastUpdateTime(lastCallTime);
+	if( mChatRoom ){
+		QDateTime lastDateTime = QDateTime::fromMSecsSinceEpoch(mChatRoom->getLastUpdateTime()*1000);
+		QDateTime lastCallTime = lastDateTime;
+		for(auto e : mEntries){
+			if(e->mType == CallEntry && e->getTimestamp() > lastCallTime)
+				lastCallTime = e->getTimestamp();
+		}	
+		setLastUpdateTime(lastCallTime);
+	}
 }
 
 void ChatRoomModel::setUnreadMessagesCount(const int& count){
+	updateNewMessageNotice(count);
 	if(count != mUnreadMessagesCount){
 		mUnreadMessagesCount = count;
 		emit unreadMessagesCountChanged();
@@ -592,6 +647,27 @@ void ChatRoomModel::setEphemeralLifetime(long lifetime){
 	}
 }
 
+void ChatRoomModel::enableMarkAsRead(const bool& enable){
+	if( mMarkAsReadEnabled != enable){
+		mMarkAsReadEnabled = enable;
+		emit markAsReadEnabledChanged();
+	}
+}
+
+void ChatRoomModel::setReply(ChatMessageModel * model){
+	if(model != mReplyModel.get()){
+		if( model && model->getChatMessage() )
+			mReplyModel = ChatMessageModel::create(model->getChatMessage(), this);
+		else
+			mReplyModel = nullptr;
+		emit replyChanged();
+	}
+}
+
+ChatMessageModel * ChatRoomModel::getReply()const{
+	return mReplyModel.get();
+}
+
 //------------------------------------------------------------------------------------------------
 
 void ChatRoomModel::deleteChatRoom(){
@@ -630,44 +706,61 @@ void ChatRoomModel::updateParticipants(const QVariantList& participants){
 // -----------------------------------------------------------------------------
 
 void ChatRoomModel::sendMessage (const QString &message) {
-	shared_ptr<linphone::ChatMessage> _message = mChatRoom->createMessageFromUtf8(message.toUtf8().toStdString());
-	_message->send();
-	
-	emit messageSent(_message);
-}
-
-void ChatRoomModel::sendFileMessage (const QString &path) {
-	
-	QFile file(path);
-	if (!file.exists())
-		return;
-	
-	qint64 fileSize = file.size();
-	if (fileSize > Constants::FileSizeLimit) {
-		qWarning() << QStringLiteral("Unable to send file. (Size limit=%1)").arg(Constants::FileSizeLimit);
-		return;
-	}
-	
-	shared_ptr<linphone::Content> content = CoreManager::getInstance()->getCore()->createContent();
-	{
-		QStringList mimeType = QMimeDatabase().mimeTypeForFile(path).name().split('/');
-		if (mimeType.length() != 2) {
-			qWarning() << QStringLiteral("Unable to get supported mime type for: `%1`.").arg(path);
-			return;
+	std::list<shared_ptr<linphone::ChatMessage> > _messages;
+	bool isBasicChatRoom = isBasic();
+	if(mReplyModel && mReplyModel->getChatMessage()) {
+		_messages.push_back(mChatRoom->createReplyMessage(mReplyModel->getChatMessage()));
+	}else
+		 _messages.push_back(mChatRoom->createEmptyMessage());
+	auto recorder = CoreManager::getInstance()->getRecorderManager();
+	if(recorder->haveVocalRecorder()) {
+		recorder->getVocalRecorder()->stop();
+		auto content = recorder->getVocalRecorder()->getRecorder()->createContent();
+		if(content) {
+			_messages.back()->addContent(content);
 		}
-		content->setType(Utils::appStringToCoreString(mimeType[0]));
-		content->setSubtype(Utils::appStringToCoreString(mimeType[1]));
 	}
-	content->setSize(size_t(fileSize)); 
-	content->setName(QFileInfo(file).fileName().toStdString());
-
-	shared_ptr<linphone::ChatMessage> message = mChatRoom->createFileTransferMessage(content);
-	message->getContents().front()->setFilePath(Utils::appStringToCoreString(path));
-	message->send();
-	
-	emit messageSent(message);
+	auto fileContents = CoreManager::getInstance()->getChatModel()->getContentListModel()->getContents();
+	for(auto content : fileContents){
+		if(isBasicChatRoom && _messages.back()->getContents().size() > 0)	// Basic chat rooms don't support multipart
+			_messages.push_back(mChatRoom->createEmptyMessage());
+		_messages.back()->addFileContent(content->getContent());
+	}
+	if(!message.isEmpty()) {
+		if(isBasicChatRoom && _messages.back()->getContents().size() > 0)	// Basic chat rooms don't support multipart
+			_messages.push_back(mChatRoom->createEmptyMessage());
+		_messages.back()->addUtf8TextContent(message.toUtf8().toStdString());
+	}
+	bool sent = false;
+	for(auto itMessage = _messages.begin() ; itMessage != _messages.end() ; ++itMessage) {
+		if((*itMessage)->getContents().size() > 0){// Have something to send
+			(*itMessage)->send();
+			emit messageSent((*itMessage));
+			sent = true;
+		}
+	}
+	if(sent){
+		setReply(nullptr);
+		if(recorder->haveVocalRecorder())
+			recorder->clearVocalRecorder();
+		CoreManager::getInstance()->getChatModel()->clear();
+	}
 }
 
+void ChatRoomModel::forwardMessage(ChatMessageModel * model){
+	if(model){
+		shared_ptr<linphone::ChatMessage> _message;
+		_message = mChatRoom->createForwardMessage(model->getChatMessage());
+		auto recorder = CoreManager::getInstance()->getRecorderManager();
+		if(recorder->haveVocalRecorder()) {
+			auto content = recorder->getVocalRecorder()->getRecorder()->createContent();
+			if(content)
+				_message->addContent(content);
+		}
+		_message->send();
+		emit messageSent(_message);
+	}
+}
 // -----------------------------------------------------------------------------
 
 void ChatRoomModel::compose () {
@@ -676,7 +769,7 @@ void ChatRoomModel::compose () {
 }
 
 void ChatRoomModel::resetMessageCount () {
-	if(mChatRoom && !mDeleteChatRoom){
+	if(mChatRoom && !mDeleteChatRoom && markAsReadEnabled()){
 		if (mChatRoom->getUnreadMessagesCount() > 0){
 			mChatRoom->markAsRead();// Marking as read is only for messages. Not for calls.
 		}
@@ -758,108 +851,209 @@ public:
 					}
 				}
 			}else{
-			auto entry = ChatNoticeModel::create(std::dynamic_pointer_cast<linphone::EventLog>(itEntries->mObject), chatRoomModel);
-				if(entry)
+				auto entry = ChatNoticeModel::create(std::dynamic_pointer_cast<linphone::EventLog>(itEntries->mObject), chatRoomModel);
+				if(entry) {
 					*resultEntries << entry;
+				}
 			}	
 		}
 	}
 };
-void ChatRoomModel::initEntries(){
-// On call : reinitialize all entries. This allow to free up memory
-	QList<std::shared_ptr<ChatEvent> > entries;
-	QList<EntrySorterHelper> prepareEntries;
-// Get chat messages
-	for (auto &message : mChatRoom->getHistory(mLastEntriesStep))
-		prepareEntries << EntrySorterHelper(message->getTime() ,MessageEntry, message);
-// Get events
-	for(auto &eventLog : mChatRoom->getHistoryEvents(mLastEntriesStep))
-		prepareEntries << EntrySorterHelper(eventLog->getCreationTime() , NoticeEntry, eventLog);
-// Get calls.
-	if(!isSecure() ) {
-		auto callHistory = CoreManager::getInstance()->getCore()->getCallHistory(mChatRoom->getPeerAddress(), mChatRoom->getLocalAddress());
-		// callhistory is sorted from newest to oldest
-		int count = 0;
-		for (auto callLog = callHistory.begin() ; count < mLastEntriesStep && callLog != callHistory.end() ; ++callLog, ++count ){
-			prepareEntries << EntrySorterHelper((*callLog)->getStartDate(), CallEntry, *callLog);
+
+void ChatRoomModel::updateNewMessageNotice(const int& count){
+	if( mChatRoom ) {
+		if(mUnreadMessageNotice ) {
+				removeEntry(mUnreadMessageNotice.get());
+				mUnreadMessageNotice = nullptr;
 		}
+		if(count > 0){
+			QDateTime lastUnreadMessage = QDateTime::currentDateTime();
+			enableMarkAsRead(false);
+// Get chat messages
+			for (auto &message : mChatRoom->getHistory(mLastEntriesStep)) {
+				if( !message->isRead()) {
+					lastUnreadMessage = min(lastUnreadMessage, QDateTime::fromMSecsSinceEpoch(message->getTime() * 1000 - 1 ));	//-1 to be sure that event will be before the message
+				}
+			}			
+			mUnreadMessageNotice = ChatNoticeModel::create(ChatNoticeModel::NoticeType::NoticeUnreadMessages, lastUnreadMessage, QString::number(count));
+			beginInsertRows(QModelIndex(), 0, 0);
+			mEntries.prepend(mUnreadMessageNotice);
+			endInsertRows();
+			qDebug() << "New message notice timestamp to :" << lastUnreadMessage.toString();
+		}
+		//emit layoutChanged();
 	}
-	EntrySorterHelper::getLimitedSelection(&entries, prepareEntries, mLastEntriesStep, this);
+}
+
+int ChatRoomModel::loadTillMessage(ChatMessageModel * message){
+	if( message){
+		qDebug() << "Load history till message : " << message->getChatMessage()->getMessageId().c_str();
+		auto linphoneMessage = message->getChatMessage();
+	// First find on current list
+		auto entry = std::find_if(mEntries.begin(), mEntries.end(), [linphoneMessage](const std::shared_ptr<ChatEvent>& entry ){
+			return entry->mType == ChatRoomModel::EntryType::MessageEntry && dynamic_cast<ChatMessageModel*>(entry.get())->getChatMessage() == linphoneMessage;
+		});
+	// if not find, load more entries and find it in new entries.
+		if( entry == mEntries.end()){
+			int newEntries = loadMoreEntries();
+			while( newEntries > 0){// no more new entries
+				int entryCount = 0;
+				entry = mEntries.begin();
+				while(entryCount < newEntries && 
+					((*entry)->mType != ChatRoomModel::EntryType::MessageEntry || dynamic_cast<ChatMessageModel*>(entry->get())->getChatMessage() != linphoneMessage)
+				){
+					++entryCount;
+					++entry;
+				}
+				if( entryCount < newEntries){// We got it
+					qDebug() << "Find message at " << entryCount << " after loading new entries";
+					return entryCount;
+				}else
+					newEntries = loadMoreEntries();// continue
+			}
+		}else{
+			int entryCount = entry - mEntries.begin();
+			qDebug() << "Find message at " << entryCount;
+			return entryCount;
+		}
+		qWarning() << "Message has not been found in history";
+	}
+	return -1;
+}
+
+void ChatRoomModel::resetEntries(){
+	beginResetModel();
+	mEntries.clear();
+	endResetModel();
+}
+
+void ChatRoomModel::initEntries(){
+	if( mEntries.size() > mLastEntriesStep)
+		resetEntries();
+	if(mEntries.size() == 0) {
+		qDebug() << "Internal Entries : Init";
+	// On call : reinitialize all entries. This allow to free up memory
+		QList<std::shared_ptr<ChatEvent> > entries;
+		QList<EntrySorterHelper> prepareEntries;
+	// Get chat messages
+		for (auto &message : mChatRoom->getHistory(mFirstLastEntriesStep)) {
+			prepareEntries << EntrySorterHelper(message->getTime() ,MessageEntry, message);
+		}
+	// Get events
+		for(auto &eventLog : mChatRoom->getHistoryEvents(mFirstLastEntriesStep))
+			prepareEntries << EntrySorterHelper(eventLog->getCreationTime() , NoticeEntry, eventLog);
+	// Get calls.
+		bool secureChatEnabled = CoreManager::getInstance()->getSettingsModel()->getSecureChatEnabled();
+		bool standardChatEnabled = CoreManager::getInstance()->getSettingsModel()->getStandardChatEnabled();
 	
+		if( isOneToOne() && (secureChatEnabled && !standardChatEnabled && isSecure()
+			|| standardChatEnabled && !isSecure()) ) {
+			auto callHistory = CallsListModel::getCallHistory(getParticipantAddress(), Utils::coreStringToAppString(mChatRoom->getLocalAddress()->asStringUriOnly()));
+			// callhistory is sorted from newest to oldest
+			int count = 0;
+			for (auto callLog = callHistory.begin() ; count < mFirstLastEntriesStep && callLog != callHistory.end() ; ++callLog, ++count ){
+				prepareEntries << EntrySorterHelper((*callLog)->getStartDate(), CallEntry, *callLog);
+			}
+		}
+		EntrySorterHelper::getLimitedSelection(&entries, prepareEntries, mFirstLastEntriesStep, this);
+		qDebug() << "Internal Entries : Built";
+		if(entries.size() >0){
+			beginInsertRows(QModelIndex(),0, entries.size()-1);
+			mEntries = entries;
+			updateNewMessageNotice(mChatRoom->getUnreadMessagesCount());
+			endInsertRows();
+		}
+		qDebug() << "Internal Entries : End";
+	}
 	mIsInitialized = true;
-	if(entries.size() >0){
-		beginResetModel();
-		mEntries = entries;
-		endResetModel();
+}
+void ChatRoomModel::setEntriesLoading(const bool& loading){
+	if( mEntriesLoading != loading){
+		mEntriesLoading = loading;
+		emit entriesLoadingChanged(mEntriesLoading);
+		qApp->processEvents();
 	}
 }
 
 int ChatRoomModel::loadMoreEntries(){
-	QList<std::shared_ptr<ChatEvent> > entries;
-	QList<EntrySorterHelper> prepareEntries;
-// Get current event count for each type
-	QVector<int> entriesCounts;
-	entriesCounts.resize(3);
-	for(auto itEntries = mEntries.begin() ; itEntries != mEntries.end() ; ++itEntries){
-		if( (*itEntries)->mType == MessageEntry)
-			++entriesCounts[0];
-		else if( (*itEntries)->mType == CallEntry){
-			if(dynamic_cast<ChatCallModel*>((*itEntries).get())->mIsStart)
-				++entriesCounts[1];
-		} else
-			++entriesCounts[2];
-	}
+	setEntriesLoading(true);
+	int currentRowCount = rowCount();
+	int newEntries = 0;
+	do{
+		QList<std::shared_ptr<ChatEvent> > entries;
+		QList<EntrySorterHelper> prepareEntries;
+	// Get current event count for each type
+		QVector<int> entriesCounts;
+		entriesCounts.resize(3);
+		for(auto itEntries = mEntries.begin() ; itEntries != mEntries.end() ; ++itEntries){
+			if( (*itEntries)->mType == MessageEntry)
+				++entriesCounts[0];
+			else if( (*itEntries)->mType == CallEntry){
+				if(dynamic_cast<ChatCallModel*>((*itEntries).get())->mIsStart)
+					++entriesCounts[1];
+			} else
+				++entriesCounts[2];
+		}
+		
+	// Messages
+		for (auto &message : mChatRoom->getHistoryRange(entriesCounts[0], entriesCounts[0]+mLastEntriesStep)){
+			auto itEntries = mEntries.begin();
+			bool haveEntry = false;
+			while(!haveEntry && itEntries != mEntries.end()){
+				auto entry = dynamic_cast<ChatMessageModel*>(itEntries->get());
+				haveEntry = (entry && entry->getChatMessage() == message);
+				++itEntries;
+			}
+			if(!haveEntry)
+				prepareEntries << EntrySorterHelper(message->getTime() ,MessageEntry, message);
+		}
 	
-// Messages
-	for (auto &message : mChatRoom->getHistoryRange(entriesCounts[0], entriesCounts[0]+mLastEntriesStep)){
-		auto itEntries = mEntries.begin();
-		bool haveEntry = false;
-		while(!haveEntry && itEntries != mEntries.end()){
-			auto entry = dynamic_cast<ChatMessageModel*>(itEntries->get());
-			haveEntry = (entry && entry->getChatMessage() == message);
-			++itEntries;
+	// Calls
+		bool secureChatEnabled = CoreManager::getInstance()->getSettingsModel()->getSecureChatEnabled();
+		bool standardChatEnabled = CoreManager::getInstance()->getSettingsModel()->getStandardChatEnabled();
+	
+		if( isOneToOne() && (secureChatEnabled && !standardChatEnabled && isSecure()
+			|| standardChatEnabled && !isSecure()) ) {
+			auto callHistory = CallsListModel::getCallHistory(getParticipantAddress(), Utils::coreStringToAppString(mChatRoom->getLocalAddress()->asStringUriOnly()));
+			int count = 0;
+			auto itCallHistory = callHistory.begin();
+			while(count < entriesCounts[1] && itCallHistory != callHistory.end()){
+				++itCallHistory;
+				++count;
+			}
+			count = 0;
+			while( count < mLastEntriesStep && itCallHistory != callHistory.end()){
+				prepareEntries << EntrySorterHelper((*itCallHistory)->getStartDate(), CallEntry, *itCallHistory);
+				++itCallHistory;
+			}
 		}
-		if(!haveEntry)
-			prepareEntries << EntrySorterHelper(message->getTime() ,MessageEntry, message);
-	}
-
-// Calls
-	if(!isSecure() ) {
-		auto callHistory = CoreManager::getInstance()->getCore()->getCallHistory(mChatRoom->getPeerAddress(), mChatRoom->getLocalAddress());
-		int count = 0;
-		auto itCallHistory = callHistory.begin();
-		while(count < entriesCounts[1] && itCallHistory != callHistory.end()){
-			++itCallHistory;
-			++count;
+	// Notices
+		for (auto &eventLog : mChatRoom->getHistoryRangeEvents(entriesCounts[2], entriesCounts[2]+mLastEntriesStep)){
+			auto itEntries = mEntries.begin();
+			bool haveEntry = false;
+			while(!haveEntry && itEntries != mEntries.end()){
+				auto entry = dynamic_cast<ChatNoticeModel*>(itEntries->get());
+				haveEntry = (entry && entry->getEventLog() && entry->getEventLog() == eventLog);
+				++itEntries;
+			}
+			if(!haveEntry)
+				prepareEntries << EntrySorterHelper(eventLog->getCreationTime() , NoticeEntry, eventLog);
 		}
-		count = 0;
-		while( count < mLastEntriesStep && itCallHistory != callHistory.end()){
-			prepareEntries << EntrySorterHelper((*itCallHistory)->getStartDate(), CallEntry, *itCallHistory);
-			++itCallHistory;
+		EntrySorterHelper::getLimitedSelection(&entries, prepareEntries, mLastEntriesStep, this);
+		if(entries.size() >0){
+			beginInsertRows(QModelIndex(), 0, entries.size()-1);
+			for(auto entry : entries)
+				mEntries.prepend(entry);
+			endInsertRows();
+			//emit layoutChanged();
+			updateLastUpdateTime();
 		}
-	}
-// Notices
-	for (auto &eventLog : mChatRoom->getHistoryRangeEvents(entriesCounts[2], entriesCounts[2]+mLastEntriesStep)){
-		auto itEntries = mEntries.begin();
-		bool haveEntry = false;
-		while(!haveEntry && itEntries != mEntries.end()){
-			auto entry = dynamic_cast<ChatNoticeModel*>(itEntries->get());
-			haveEntry = (entry && entry->getEventLog() == eventLog);
-			++itEntries;
-		}
-		if(!haveEntry)
-			prepareEntries << EntrySorterHelper(eventLog->getCreationTime() , NoticeEntry, eventLog);
-	}	
-	EntrySorterHelper::getLimitedSelection(&entries, prepareEntries, mLastEntriesStep, this);
-	if(entries.size() >0){
-		beginInsertRows(QModelIndex(), 0, entries.size()-1);
-		for(auto entry : entries)
-			mEntries.prepend(entry);
-		endInsertRows();
-		emit layoutChanged();
-		updateLastUpdateTime();
-	}
-	return entries.size();
+		newEntries = entries.size();
+	}while( newEntries>0 && currentRowCount == rowCount());
+	currentRowCount = rowCount() - currentRowCount + 1;
+	setEntriesLoading(false);
+	emit moreEntriesLoaded(currentRowCount);
+	return currentRowCount;
 }
 
 //-------------------------------------------------
@@ -924,9 +1118,10 @@ void ChatRoomModel::insertCalls (const QList<std::shared_ptr<linphone::CallLog>
 	}
 }
 
-void ChatRoomModel::insertMessageAtEnd (const std::shared_ptr<linphone::ChatMessage> &message) {
+std::shared_ptr<ChatMessageModel> ChatRoomModel::insertMessageAtEnd (const std::shared_ptr<linphone::ChatMessage> &message) {
+	std::shared_ptr<ChatMessageModel> model;
 	if(mIsInitialized){
-		std::shared_ptr<ChatMessageModel> model = ChatMessageModel::create(message, this);
+		model = ChatMessageModel::create(message, this);
 		if(model){
 			setUnreadMessagesCount(mChatRoom->getUnreadMessagesCount());
 			int row = mEntries.count();
@@ -935,6 +1130,7 @@ void ChatRoomModel::insertMessageAtEnd (const std::shared_ptr<linphone::ChatMess
 			endInsertRows();
 		}
 	}
+	return model;
 }
 
 void ChatRoomModel::insertMessages (const QList<std::shared_ptr<linphone::ChatMessage> > &messages) {
@@ -946,11 +1142,11 @@ void ChatRoomModel::insertMessages (const QList<std::shared_ptr<linphone::ChatMe
 				entries << model;
 		}
 		if(entries.size() > 0){
-			setUnreadMessagesCount(mChatRoom->getUnreadMessagesCount());
 			beginInsertRows(QModelIndex(), 0, entries.size()-1);
 			entries << mEntries;
 			mEntries = entries;
 			endInsertRows();
+			setUnreadMessagesCount(mChatRoom->getUnreadMessagesCount());
 			emit layoutChanged();
 		}
 	}
@@ -974,8 +1170,9 @@ void ChatRoomModel::insertNotices (const QList<std::shared_ptr<linphone::EventLo
 		
 		for(auto eventLog : eventLogs) {
 			std::shared_ptr<ChatNoticeModel> model = ChatNoticeModel::create(eventLog, this);
-			if(model)
+			if(model) {
 				entries << model;
+			}
 		}
 		
 		if(entries.size() > 0){
@@ -987,6 +1184,12 @@ void ChatRoomModel::insertNotices (const QList<std::shared_ptr<linphone::EventLo
 		}
 	}
 }
+
+// -----------------------------------------------------------------------------
+/*
+void ChatRoomModel::removeUnreadMessagesNotice() {
+	
+}*/
 // -----------------------------------------------------------------------------
 
 void ChatRoomModel::handleCallStateChanged (const std::shared_ptr<linphone::Call> &call, linphone::Call::State state) {
@@ -1176,7 +1379,7 @@ void ChatRoomModel::onConferenceJoined(const std::shared_ptr<linphone::ChatRoom>
 	updateLastUpdateTime();
 	emit usernameChanged();
 	emit conferenceJoined(chatRoom, eventLog);
-	emit hasBeenLeftChanged();
+	emit isReadOnlyChanged();
 }
 
 void ChatRoomModel::onConferenceLeft(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog){
@@ -1193,7 +1396,7 @@ void ChatRoomModel::onConferenceLeft(const std::shared_ptr<linphone::ChatRoom> &
 		}
 		updateLastUpdateTime();
 		emit conferenceLeft(chatRoom, eventLog);
-		emit hasBeenLeftChanged();
+		emit isReadOnlyChanged();
 	}
 }
 
