@@ -149,7 +149,7 @@ void ConferenceHelperModel::ConferenceAddModel::update () {
   shared_ptr<linphone::Conference> conference = mConferenceHelperModel->mCore->getConference();
   if(!conference){
     auto parameters = mConferenceHelperModel->mCore->createConferenceParams();
-    parameters->setVideoEnabled(false);// Video is not yet fully supported by the application in conference
+    parameters->enableVideo(false);// Video is not yet fully supported by the application in conference
     conference = mConferenceHelperModel->mCore->createConferenceWithParams(parameters);
   }
   auto currentCalls = CoreManager::getInstance()->getCore()->getCalls();
