@@ -62,7 +62,17 @@ AccountSettingsModel::AccountSettingsModel (QObject *parent) : QObject(parent) {
 				coreManager->getHandlers().get(), &CoreHandlers::registrationStateChanged,
 				this, &AccountSettingsModel::handleRegistrationStateChanged
 				);
-	QObject::connect(coreManager, &CoreManager::eventCountChanged, this, [this]() { emit accountSettingsUpdated(); });
+	//QObject::connect(coreManager, &CoreManager::eventCountChanged, this, [this]() { emit accountSettingsUpdated(); });
+	
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::usernameChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::sipAddressChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::fullSipAddressChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::registrationStateChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::conferenceURIChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::primaryDisplayNameChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::primaryUsernameChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::primarySipAddressChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::accountsChanged);
 }
 
 // -----------------------------------------------------------------------------
@@ -79,6 +89,7 @@ void AccountSettingsModel::setUsedSipAddress (const shared_ptr<const linphone::A
 	shared_ptr<linphone::ProxyConfig> proxyConfig = core->getDefaultProxyConfig();
 	
 	proxyConfig ? proxyConfig->setIdentityAddress(address) : core->setPrimaryContact(address->asString());
+	emit sipAddressChanged();
 }
 
 QString AccountSettingsModel::getUsedSipAddressAsStringUriOnly () const {
@@ -231,8 +242,10 @@ void AccountSettingsModel::removeProxyConfig (const shared_ptr<linphone::ProxyCo
 	if (proxyConfig->done() == -1) {
 		qWarning() << QStringLiteral("Unable to reset message-expiry property before removing proxy config: `%1`.")
 				  .arg(QString::fromStdString(proxyConfig->getIdentityAddress()->asString()));
-	}else { // Wait for update
+	}else if(proxyConfig->registerEnabled()) { // Wait for update
 		mRemovingProxies.push_back(proxyConfig);
+	}else{// Registration is not enabled : Removing without wait.
+		CoreManager::getInstance()->getCore()->removeProxyConfig(proxyConfig);
 	}
 	
 	emit accountSettingsUpdated();
@@ -251,7 +264,8 @@ bool AccountSettingsModel::addOrUpdateProxyConfig (
 	
 	// Sip address.
 	{
-		shared_ptr<linphone::Address> address = linphone::Factory::get()->createAddress(Utils::appStringToCoreString(literal));
+		
+		shared_ptr<linphone::Address> address = Utils::interpretUrl(literal);
 		if (!address) {
 			qWarning() << QStringLiteral("Unable to create sip address object from: `%1`.").arg(literal);
 			return false;
@@ -274,17 +288,26 @@ bool AccountSettingsModel::addOrUpdateProxyConfig (
 		}
 	}
 	
-	proxyConfig->setPublishExpires(data["registrationDuration"].toInt());
-	proxyConfig->setRoute(Utils::appStringToCoreString(data["route"].toString()));
+	if(data.contains("registrationDuration"))
+		proxyConfig->setPublishExpires(data["registrationDuration"].toInt());
+	if(data.contains("route"))
+		proxyConfig->setRoute(Utils::appStringToCoreString(data["route"].toString()));
 	QString conferenceURI = data["conferenceUri"].toString();
 	if(!conferenceURI.isEmpty())
 		proxyConfig->setConferenceFactoryUri(Utils::appStringToCoreString(conferenceURI));
-	proxyConfig->setContactParameters(Utils::appStringToCoreString(data["contactParams"].toString()));
-	proxyConfig->setAvpfRrInterval(uint8_t(data["avpfInterval"].toInt()));
-	proxyConfig->enableRegister(data["registerEnabled"].toBool());
-	newPublishPresence = proxyConfig->publishEnabled() != data["publishPresence"].toBool();
-	proxyConfig->enablePublish(data["publishPresence"].toBool());
-	proxyConfig->setAvpfMode(data["avpfEnabled"].toBool()
+	if(data.contains("contactParams"))
+		proxyConfig->setContactParameters(Utils::appStringToCoreString(data["contactParams"].toString()));
+	if(data.contains("avpfInterval"))
+		proxyConfig->setAvpfRrInterval(uint8_t(data["avpfInterval"].toInt()));
+	if(data.contains("registerEnabled"))
+		proxyConfig->enableRegister(data.contains("registerEnabled") ? data["registerEnabled"].toBool() : true);
+	if(data.contains("publishPresence")) {
+		newPublishPresence = proxyConfig->publishEnabled() != data["publishPresence"].toBool();
+		proxyConfig->enablePublish(data["publishPresence"].toBool());
+	}else
+		newPublishPresence = proxyConfig->publishEnabled();
+	if(data.contains("avpfEnabled"))
+		proxyConfig->setAvpfMode(data["avpfEnabled"].toBool()
 			? linphone::AVPFMode::Enabled
 			: linphone::AVPFMode::Default
 			  );
@@ -293,13 +316,17 @@ bool AccountSettingsModel::addOrUpdateProxyConfig (
 	bool createdNat = !natPolicy;
 	if (createdNat)
 		natPolicy = proxyConfig->getCore()->createNatPolicy();
-	natPolicy->enableIce(data["iceEnabled"].toBool());
-	natPolicy->enableStun(data["iceEnabled"].toBool());
-	
-	const string turnUser(Utils::appStringToCoreString(data["turnUser"].toString()));
-	const string stunServer(Utils::appStringToCoreString(data["stunServer"].toString()));
-	
-	natPolicy->enableTurn(data["turnEnabled"].toBool());
+	if(data.contains("iceEnabled"))
+		natPolicy->enableIce(data["iceEnabled"].toBool());
+	if(data.contains("iceEnabled"))
+		natPolicy->enableStun(data["iceEnabled"].toBool());
+	string turnUser, stunServer;
+	if(data.contains("turnUser"))
+		turnUser = Utils::appStringToCoreString(data["turnUser"].toString());
+	if(data.contains("stunServer"))
+		stunServer = Utils::appStringToCoreString(data["stunServer"].toString());
+	if(data.contains("turnEnabled"))
+		natPolicy->enableTurn(data["turnEnabled"].toBool());
 	natPolicy->setStunServerUsername(turnUser);
 	natPolicy->setStunServer(stunServer);
 	
@@ -313,7 +340,6 @@ bool AccountSettingsModel::addOrUpdateProxyConfig (
 		clonedAuthInfo->setUserid(turnUser);
 		clonedAuthInfo->setUsername(turnUser);
 		clonedAuthInfo->setPassword(Utils::appStringToCoreString(data["turnPassword"].toString()));
-		
 		core->addAuthInfo(clonedAuthInfo);
 		core->removeAuthInfo(authInfo);
 	} else
@@ -330,13 +356,27 @@ bool AccountSettingsModel::addOrUpdateProxyConfig (
 	return addOrUpdateProxyConfig(proxyConfig);
 }
 
-shared_ptr<linphone::ProxyConfig> AccountSettingsModel::createProxyConfig () {
+bool AccountSettingsModel::addOrUpdateProxyConfig (
+  const QVariantMap &data
+) {
+	shared_ptr<linphone::ProxyConfig> proxyConfig;
+	QString sipAddress = data["sipAddress"].toString();
+	shared_ptr<linphone::Address> address = CoreManager::getInstance()->getCore()->interpretUrl(sipAddress.toStdString());
+	
+	for (const auto &databaseProxyConfig : CoreManager::getInstance()->getCore()->getProxyConfigList())
+	  if (databaseProxyConfig->getIdentityAddress()->weakEqual(address)) {
+		proxyConfig = databaseProxyConfig;
+	  }
+	if(!proxyConfig)
+		proxyConfig = createProxyConfig(data.contains("configFilename") ? data["configFilename"].toString() : "create-app-sip-account.rc" );
+	return addOrUpdateProxyConfig(proxyConfig, data);
+}
+
+shared_ptr<linphone::ProxyConfig> AccountSettingsModel::createProxyConfig (const QString& assistantFile) {
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	
-	core->getConfig()->loadFromXmlFile(
-				Paths::getAssistantConfigDirPath() + "create-app-sip-account.rc"
-  );
-	
+	qInfo() << QStringLiteral("Set config on assistant: `%1`.").arg(assistantFile);
+	core->getConfig()->loadFromXmlFile(Paths::getAssistantConfigDirPath() + assistantFile.toStdString());
+	core->enableLimeX3Dh(core->getLimeX3DhServerUrl() != "");
 	return core->createProxyConfig();
 }
 
@@ -376,7 +416,7 @@ void AccountSettingsModel::setUsername (const QString &username) {
 						  .arg(Utils::coreStringToAppString(newAddress->asStringUriOnly()));
 		} else {
 			setUsedSipAddress(newAddress);
-			emit accountSettingsUpdated();
+			emit usernameChanged();
 		}
 	}
 }
@@ -404,7 +444,7 @@ void AccountSettingsModel::setPrimaryUsername (const QString &username) {
 								 username.isEmpty() ? APPLICATION_NAME : username
 													  ));
 		core->setPrimaryContact(primary->asString());
-		emit accountSettingsUpdated();
+		emit primaryUsernameChanged();
 	}
 }
 
@@ -420,7 +460,7 @@ void AccountSettingsModel::setPrimaryDisplayName (const QString &displayName) {
 	if(oldDisplayName != displayName){
 		primary->setDisplayName(Utils::appStringToCoreString(displayName));
 		core->setPrimaryContact(primary->asString());
-		emit accountSettingsUpdated();
+		emit primaryDisplayNameChanged();
 	}
 }
 
@@ -438,9 +478,12 @@ QVariantList AccountSettingsModel::getAccounts () const {
 	
 	if(CoreManager::getInstance()->getSettingsModel()->getShowLocalSipAccount()) {
 		QVariantMap account;
-		account["sipAddress"] = Utils::coreStringToAppString(core->createPrimaryContactParsed()->asStringUriOnly());
-		account["fullSipAddress"] = Utils::coreStringToAppString(core->createPrimaryContactParsed()->asString());
-		account["unreadMessageCount"] = core->getUnreadChatMessageCountFromLocal(core->createPrimaryContactParsed());
+		auto address = core->createPrimaryContactParsed();
+		int unreadChatMessageCount = CoreManager::getInstance()->getUnreadChatMessage(address);
+		
+		account["sipAddress"] = Utils::coreStringToAppString(address->asStringUriOnly());
+		account["fullSipAddress"] = Utils::coreStringToAppString(address->asString());
+		account["unreadMessageCount"] = unreadChatMessageCount;
 		account["missedCallCount"] = CoreManager::getInstance()->getMissedCallCountFromLocal(account["sipAddress"].toString());
 		account["proxyConfig"].setValue(nullptr);
 		accounts << account;
@@ -448,10 +491,13 @@ QVariantList AccountSettingsModel::getAccounts () const {
 	
 	for (const auto &proxyConfig : core->getProxyConfigList()) {
 		QVariantMap account;
-		account["sipAddress"] = Utils::coreStringToAppString(proxyConfig->getIdentityAddress()->asStringUriOnly());
-		account["fullSipAddress"] = Utils::coreStringToAppString(proxyConfig->getIdentityAddress()->asString());
+		
+		auto proxyAddress = proxyConfig->getIdentityAddress();
+		int unreadChatMessageCount = CoreManager::getInstance()->getUnreadChatMessage(proxyAddress);
+		account["sipAddress"] = Utils::coreStringToAppString(proxyAddress->asStringUriOnly());
+		account["fullSipAddress"] = Utils::coreStringToAppString(proxyAddress->asString());
 		account["proxyConfig"].setValue(proxyConfig);
-		account["unreadMessageCount"] = proxyConfig->getUnreadChatMessageCount();
+		account["unreadMessageCount"] = unreadChatMessageCount;
 		account["missedCallCount"] = CoreManager::getInstance()->getMissedCallCountFromLocal(account["sipAddress"].toString());
 		accounts << account;
 	}
@@ -478,11 +524,12 @@ void AccountSettingsModel::handleRegistrationStateChanged (
 		coreManager->getSettingsModel()->configureRlsUri();
 	}else if(mRemovingProxies.contains(proxy)){
 		mRemovingProxies.removeAll(proxy);
-		QTimer::singleShot(100, [proxy](){// removeProxyConfig cannot be called from callback
+		QTimer::singleShot(100, [proxy, this](){// removeProxyConfig cannot be called from callback
 				CoreManager::getInstance()->getCore()->removeProxyConfig(proxy);
+				emit accountsChanged();
 		});
 	}
 	if(defaultProxyConfig == proxy)
 		emit defaultRegistrationChanged();
-	emit accountSettingsUpdated();
+	emit registrationStateChanged();
 }
