@@ -26,6 +26,8 @@
 #include <cstdlib>
 #include <cmath>
 
+#include "config.h"
+
 #include "app/App.hpp"
 #include "app/logger/Logger.hpp"
 #include "app/paths/Paths.hpp"
@@ -163,6 +165,71 @@ void SettingsModel::setAssistantSupportsPhoneNumbers (bool status) {
 	emit assistantSupportsPhoneNumbersChanged(status);
 }
 
+bool SettingsModel::useWebview() const{
+#ifdef ENABLE_APP_WEBVIEW
+	return true;
+#else
+	return false;
+#endif
+}
+
+QString SettingsModel::getAssistantRegistrationUrl () const {
+	return Utils::coreStringToAppString(mConfig->getString(UiSection, "assistant_registration_url", Constants::DefaultAssistantRegistrationUrl));
+}
+
+void SettingsModel::setAssistantRegistrationUrl (QString url) {
+	mConfig->setString(UiSection, "assistant_registration_url", Utils::appStringToCoreString(url));
+	emit assistantRegistrationUrlChanged(url);
+}
+
+QString SettingsModel::getAssistantLoginUrl () const {
+	return Utils::coreStringToAppString(mConfig->getString(UiSection, "assistant_login_url", Constants::DefaultAssistantLoginUrl));
+}
+
+void SettingsModel::setAssistantLoginUrl (QString url) {
+	mConfig->setString(UiSection, "assistant_login_url", Utils::appStringToCoreString(url));
+	emit assistantLoginUrlChanged(url);
+}
+
+QString SettingsModel::getAssistantLogoutUrl () const {
+	return Utils::coreStringToAppString(mConfig->getString(UiSection, "assistant_logout_url", Constants::DefaultAssistantLogoutUrl));
+}
+
+void SettingsModel::setAssistantLogoutUrl (QString url) {
+	mConfig->setString(UiSection, "assistant_logout_url", Utils::appStringToCoreString(url));
+	emit assistantLogoutUrlChanged(url);
+}
+
+bool SettingsModel::isCguAccepted () const{
+	return !!mConfig->getInt(UiSection, "read_and_agree_terms_and_privacy", 0);
+}
+
+void SettingsModel::acceptCgu(const bool accept){
+	bool oldAccept = isCguAccepted();
+	if( oldAccept != accept){
+		mConfig->setInt(UiSection, "read_and_agree_terms_and_privacy", accept);
+		emit cguAcceptedChanged(accept);
+	}
+}
+
+// =============================================================================
+// SIP Accounts.
+// =============================================================================
+
+QString SettingsModel::getDeviceName(const std::shared_ptr<linphone::Config>& config){
+	return Utils::coreStringToAppString(config->getString(UiSection, "device_name", Utils::appStringToCoreString(QSysInfo::machineHostName())));
+}
+
+QString SettingsModel::getDeviceName() const{
+	return getDeviceName(mConfig);
+}
+
+void SettingsModel::setDeviceName(const QString& deviceName){
+	mConfig->setString(UiSection, "device_name", Utils::appStringToCoreString(deviceName));
+	emit deviceNameChanged();
+	CoreManager::getInstance()->updateUserAgent();
+}
+
 // =============================================================================
 // Audio.
 // =============================================================================
@@ -283,9 +350,7 @@ void SettingsModel::setCaptureDevice (const QString &device) {
 		CoreManager::getInstance()->getCore()->setCaptureDevice(devId);
 		CoreManager::getInstance()->getCore()->setInputAudioDevice(*audioDevice);
 		emit captureDeviceChanged(device);
-		if (mSimpleCaptureGraph && mSimpleCaptureGraph->isRunning()) {
-			createCaptureGraph();
-		}
+		createCaptureGraph();
 	}else
 		qWarning() << "Cannot set Capture device. The ID cannot be matched with an existant device : " << device;
 }
@@ -309,9 +374,7 @@ void SettingsModel::setPlaybackDevice (const QString &device) {
 		CoreManager::getInstance()->getCore()->setPlaybackDevice(devId);
 		CoreManager::getInstance()->getCore()->setOutputAudioDevice(*audioDevice);
 		emit playbackDeviceChanged(device);
-		if (mSimpleCaptureGraph && mSimpleCaptureGraph->isRunning()) {
-			createCaptureGraph();
-		}
+		createCaptureGraph();
 	}else
 		qWarning() << "Cannot set Playback device. The ID cannot be matched with an existant device : " << device;
 }
@@ -582,6 +645,17 @@ void SettingsModel::setAutomaticallyRecordCalls (bool status) {
 	emit automaticallyRecordCallsChanged(status);
 }
 
+int SettingsModel::getAutoDownloadMaxSize() const{
+	return CoreManager::getInstance()->getCore()->getMaxSizeForAutoDownloadIncomingFiles();
+}
+
+void SettingsModel::setAutoDownloadMaxSize(int maxSize){
+	if(maxSize != getAutoDownloadMaxSize()){
+		CoreManager::getInstance()->getCore()->setMaxSizeForAutoDownloadIncomingFiles(maxSize);
+		emit autoDownloadMaxSizeChanged(maxSize);
+	}
+}
+	
 // -----------------------------------------------------------------------------
 
 bool SettingsModel::getCallPauseEnabled () const {
@@ -662,6 +736,17 @@ void SettingsModel::setConferenceEnabled (bool status) {
 
 // -----------------------------------------------------------------------------
 
+bool SettingsModel::getChatNotificationsEnabled () const {
+	return !!mConfig->getInt(UiSection, "chat_notifications_enabled", 1);
+}
+
+void SettingsModel::setChatNotificationsEnabled (bool status) {
+	mConfig->setInt(UiSection, "chat_notifications_enabled", status);
+	emit chatNotificationsEnabledChanged(status);
+}
+
+// -----------------------------------------------------------------------------
+
 bool SettingsModel::getChatNotificationSoundEnabled () const {
 	return !!mConfig->getInt(UiSection, "chat_sound_notification_enabled", 1);
 }
@@ -1274,13 +1359,42 @@ void SettingsModel::setCheckForUpdateEnabled(bool enable){
 }
 
 QString SettingsModel::getVersionCheckUrl() const{
-	return Utils::coreStringToAppString(mConfig->getString("misc", "version_check_url_root", Constants::VersionCheckUrl));
+	return Utils::coreStringToAppString(mConfig->getString("misc", "version_check_url_root", Constants::VersionCheckReleaseUrl));
 }
 
 void SettingsModel::setVersionCheckUrl(const QString& url){
-	mConfig->setString("misc", "version_check_url_root", Utils::appStringToCoreString(url));
-	emit versionCheckUrlChanged();
+	if( url != getVersionCheckUrl()){
+		mConfig->setString("misc", "version_check_url_root", Utils::appStringToCoreString(url));
+		if( url == Constants::VersionCheckReleaseUrl)
+			setVersionCheckType(VersionCheckType_Release);
+		else if( url == Constants::VersionCheckNightlyUrl)
+			setVersionCheckType(VersionCheckType_Nightly);
+		else
+			setVersionCheckType(VersionCheckType_Custom);
+		emit versionCheckUrlChanged();
+	}
 }
+
+SettingsModel::VersionCheckType SettingsModel::getVersionCheckType() const{
+	return (SettingsModel::VersionCheckType) mConfig->getInt(UiSection, "version_check_type", (int)VersionCheckType_Release);
+}
+
+void SettingsModel::setVersionCheckType(const VersionCheckType& type){
+	if( type != getVersionCheckType()){
+		mConfig->setInt(UiSection, "version_check_type", (int)type);
+		switch(type){
+			case VersionCheckType_Release : setVersionCheckUrl(Constants::VersionCheckReleaseUrl); break;
+			case VersionCheckType_Nightly : setVersionCheckUrl(Constants::VersionCheckNightlyUrl);break;
+			case VersionCheckType_Custom : break;// Do not override URL
+		}
+		emit versionCheckTypeChanged();
+	}
+}
+
+bool SettingsModel::haveVersionNightlyUrl()const{
+	return QString(Constants::VersionCheckNightlyUrl) != "";
+}
+
 // -----------------------------------------------------------------------------
 
 bool SettingsModel::getShowLocalSipAccount()const{
@@ -1296,18 +1410,23 @@ bool SettingsModel::getShowStartVideoCallButton ()const{
 }
 
 bool SettingsModel::isMipmapEnabled() const{
-#ifdef __APPLE__
-	return !!mConfig->getInt(UiSection, "mipmap_enabled", 1);
-#else
 	return !!mConfig->getInt(UiSection, "mipmap_enabled", 0);
-#endif
 }
 
 void SettingsModel::setMipmapEnabled(const bool& enabled){
 	mConfig->setInt(UiSection, "mipmap_enabled", enabled);
 	emit mipmapEnabledChanged();
 }
-	
+
+bool SettingsModel::useMinimalTimelineFilter() const{
+	return !!mConfig->getInt(UiSection, "use_minimal_timeline_filter", 1);
+}
+
+void SettingsModel::setUseMinimalTimelineFilter(const bool& useMinimal) {
+	mConfig->setInt(UiSection, "use_minimal_timeline_filter", useMinimal);
+	emit useMinimalTimelineFilterChanged();
+}
+
 // =============================================================================
 // Advanced.
 // =============================================================================
@@ -1381,6 +1500,10 @@ void SettingsModel::setLogsEmail (const QString &email) {
 	emit logsEmailChanged(email);
 }
 
+bool SettingsModel::isLdapAvailable(){
+	return CoreManager::getInstance()->getCore()->ldapAvailable();
+}
+
 // ---------------------------------------------------------------------------
 
 QString SettingsModel::getLogsFolder (const shared_ptr<linphone::Config> &config) {
@@ -1439,4 +1562,4 @@ bool SettingsModel::isReadOnly(const std::string& section, const std::string& na
 
 std::string SettingsModel::getEntryFullName(const std::string& section, const std::string& name) const {
 	return isReadOnly(section, name)?name+"/readonly" : name;
-}
\ No newline at end of file
+}
