@@ -24,7 +24,7 @@
 #include <QtDebug>
 
 #include "components/call/CallModel.hpp"
-#include "components/chat/ChatModel.hpp"
+#include "components/chat-room/ChatRoomModel.hpp"
 #include "components/contact/ContactModel.hpp"
 #include "components/contact/VcardModel.hpp"
 #include "components/contacts/ContactsListModel.hpp"
@@ -32,7 +32,6 @@
 #include "components/core/CoreManager.hpp"
 #include "components/history/HistoryModel.hpp"
 #include "components/settings/AccountSettingsModel.hpp"
-#include "utils/LinphoneUtils.hpp"
 #include "utils/Utils.hpp"
 
 #include "SipAddressesModel.hpp"
@@ -46,7 +45,7 @@ using namespace std;
 static inline QVariantMap buildVariantMap (const SipAddressesModel::SipAddressEntry &sipAddressEntry) {
   return QVariantMap{
     { "sipAddress", sipAddressEntry.sipAddress },
-    { "contact", QVariant::fromValue(sipAddressEntry.contact) },
+    { "contactModel", QVariant::fromValue(sipAddressEntry.contact) },
     { "presenceStatus", sipAddressEntry.presenceStatus },
     { "__localToConferenceEntry", QVariant::fromValue(&sipAddressEntry.localAddressToConferenceEntry) }
   };
@@ -59,7 +58,7 @@ SipAddressesModel::SipAddressesModel (QObject *parent) : QAbstractListModel(pare
 
   mCoreHandlers = coreManager->getHandlers();
 
-  QObject::connect(coreManager, &CoreManager::chatModelCreated, this, &SipAddressesModel::handleChatModelCreated);
+  QObject::connect(coreManager, &CoreManager::chatRoomModelCreated, this, &SipAddressesModel::handleChatRoomModelCreated);
   QObject::connect(coreManager, &CoreManager::historyModelCreated, this, &SipAddressesModel::handleHistoryModelCreated);
 
   ContactsListModel *contacts = CoreManager::getInstance()->getContactsListModel();
@@ -108,18 +107,20 @@ QVariant SipAddressesModel::data (const QModelIndex &index, int role) const {
 // -----------------------------------------------------------------------------
 
 QVariantMap SipAddressesModel::find (const QString &sipAddress) const {
-  auto it = mPeerAddressToSipAddressEntry.find(sipAddress);
-  if (it == mPeerAddressToSipAddressEntry.end())
-    return QVariantMap();
+	QString cleanedAddress = Utils::cleanSipAddress(sipAddress);
+	auto it = mPeerAddressToSipAddressEntry.find(cleanedAddress);
+	if (it == mPeerAddressToSipAddressEntry.end())
+		return QVariantMap();
 
-  return buildVariantMap(*it);
+	return buildVariantMap(*it);
 }
 
 // -----------------------------------------------------------------------------
 
 ContactModel *SipAddressesModel::mapSipAddressToContact (const QString &sipAddress) const {
-  auto it = mPeerAddressToSipAddressEntry.find(sipAddress);
-  return it == mPeerAddressToSipAddressEntry.end() ? nullptr : it->contact;
+	QString cleanedAddress = Utils::cleanSipAddress(sipAddress);
+	auto it = mPeerAddressToSipAddressEntry.find(cleanedAddress);
+	return it == mPeerAddressToSipAddressEntry.end() ? nullptr : it->contact;
 }
 
 // -----------------------------------------------------------------------------
@@ -155,10 +156,7 @@ SipAddressObserver *SipAddressesModel::getSipAddressObserver (const QString &pee
 QString SipAddressesModel::getTransportFromSipAddress (const QString &sipAddress) {
     if( sipAddress.toUpper().contains("TRANSPORT="))
     {// Transport has been specified : check for it
-      const shared_ptr<const linphone::Address> address = linphone::Factory::get()->createAddress(
-        Utils::appStringToCoreString(sipAddress)
-      );
-
+      const shared_ptr<const linphone::Address> address = linphone::Factory::get()->createAddress(Utils::appStringToCoreString(sipAddress));
       if (!address)
         return QString("TLS");  // Return TLS by default
 
@@ -178,14 +176,12 @@ QString SipAddressesModel::getTransportFromSipAddress (const QString &sipAddress
 }
 
 QString SipAddressesModel::addTransportToSipAddress (const QString &sipAddress, const QString &transport) {
-  shared_ptr<linphone::Address> address = linphone::Factory::get()->createAddress(
-    Utils::appStringToCoreString(sipAddress)
-  );
+  shared_ptr<linphone::Address> address = linphone::Factory::get()->createAddress(Utils::appStringToCoreString(sipAddress));
 
   if (!address)
     return QString("");
 
-  address->setTransport(LinphoneUtils::stringToTransportType(transport.toUpper()));
+  address->setTransport(Utils::stringToTransportType(transport.toUpper()));
 
   return Utils::coreStringToAppString(address->asString());
 }
@@ -201,21 +197,43 @@ QString SipAddressesModel::interpretSipAddress (const QString &sipAddress, bool
     return Utils::coreStringToAppString(lAddress->asStringUriOnly());
   return QString("");
 }
+QString SipAddressesModel::interpretSipAddress (const QString &sipAddress, const QString &domain) {
+    auto core = CoreManager::getInstance()->getCore();
+    if(!core){
+        qWarning() << "No core to interpret address";
+    }else{
+      auto proxyConfig = CoreManager::getInstance()->getCore()->createProxyConfig();
+      if( !proxyConfig) {
+      }else{
+          shared_ptr<linphone::Address> lAddressTemp = core->createPrimaryContactParsed();// Create an address
+          if( lAddressTemp ){
+              lAddressTemp->setDomain(Utils::appStringToCoreString(domain));    // Set the domain and use the address into proxy
+              proxyConfig->setIdentityAddress(lAddressTemp);
+              shared_ptr<linphone::Address> lAddress = proxyConfig->normalizeSipUri(Utils::appStringToCoreString(sipAddress));
+              if (lAddress) {
+                return Utils::coreStringToAppString(lAddress->asStringUriOnly());
+              } else {
+                  qWarning() << "Cannot normalize Sip Uri : " << sipAddress << " / " << domain;
+                return QString("");
+              }
+          }else{
+              qWarning() << "Cannot create a Primary Contact Parsed";
+          }
+       }
+    }
+  return QString("");
+}
 
 QString SipAddressesModel::interpretSipAddress (const QUrl &sipAddress) {
   return sipAddress.toString();
 }
 
 bool SipAddressesModel::addressIsValid (const QString &address) {
-  return !!linphone::Factory::get()->createAddress(
-    Utils::appStringToCoreString(address)
-  );
+  return !!linphone::Factory::get()->createAddress(Utils::appStringToCoreString(address));
 }
 
 bool SipAddressesModel::sipAddressIsValid (const QString &sipAddress) {
-  shared_ptr<linphone::Address> address = linphone::Factory::get()->createAddress(
-    Utils::appStringToCoreString(sipAddress)
-  );
+  shared_ptr<linphone::Address> address = linphone::Factory::get()->createAddress(Utils::appStringToCoreString(sipAddress));
   return address && !address->getUsername().empty();
 }
 // Return at most : sip:username@domain
@@ -247,20 +265,20 @@ bool SipAddressesModel::removeRows (int row, int count, const QModelIndex &paren
 
 // -----------------------------------------------------------------------------
 
-void SipAddressesModel::handleChatModelCreated (const shared_ptr<ChatModel> &chatModel) {
-  ChatModel *ptr = chatModel.get();
+void SipAddressesModel::handleChatRoomModelCreated (const shared_ptr<ChatRoomModel> &chatRoomModel) {
+  ChatRoomModel *ptr = chatRoomModel.get();
 
-  QObject::connect(ptr, &ChatModel::allEntriesRemoved, this, [this, ptr] {
+  QObject::connect(ptr, &ChatRoomModel::allEntriesRemoved, this, [this, ptr] {
     handleAllEntriesRemoved(ptr);
   });
-  QObject::connect(ptr, &ChatModel::lastEntryRemoved, this, [this, ptr] {
+  QObject::connect(ptr, &ChatRoomModel::lastEntryRemoved, this, [this, ptr] {
     handleLastEntryRemoved(ptr);
   });
-  QObject::connect(ptr, &ChatModel::messageCountReset, this, [this, ptr] {
+  QObject::connect(ptr, &ChatRoomModel::messageCountReset, this, [this, ptr] {
     handleMessageCountReset(ptr);
   });
 
-  QObject::connect(ptr, &ChatModel::messageSent, this, &SipAddressesModel::handleMessageSent);
+  QObject::connect(ptr, &ChatRoomModel::messageSent, this, &SipAddressesModel::handleMessageSent);
 }
 
 void SipAddressesModel::handleHistoryModelCreated (HistoryModel *historyModel) {
@@ -269,8 +287,9 @@ void SipAddressesModel::handleHistoryModelCreated (HistoryModel *historyModel) {
   });
 }
 void SipAddressesModel::handleContactAdded (ContactModel *contact) {
-  for (const auto &sipAddress : contact->getVcardModel()->getSipAddresses())
-    addOrUpdateSipAddress(sipAddress.toString(), contact);
+  for (const auto &sipAddress : contact->getVcardModel()->getSipAddresses()) {
+	addOrUpdateSipAddress(sipAddress.toString(), contact);
+  }
 }
 
 void SipAddressesModel::handleContactRemoved (const ContactModel *contact) {
@@ -284,7 +303,6 @@ void SipAddressesModel::handleSipAddressAdded (ContactModel *contact, const QStr
     qWarning() << "Unable to map sip address" << sipAddress << "to" << contact << "- already used by" << mappedContact;
     return;
   }
-
   addOrUpdateSipAddress(sipAddress, contact);
 }
 
@@ -299,7 +317,6 @@ void SipAddressesModel::handleSipAddressRemoved (ContactModel *contact, const QS
 }
 
 void SipAddressesModel::handleMessageReceived (const shared_ptr<linphone::ChatMessage> &message) {
-  qInfo() << "Handle message received.";
   const QString peerAddress(Utils::coreStringToAppString(message->getChatRoom()->getPeerAddress()->asStringUriOnly()));
   addOrUpdateSipAddress(peerAddress, message);
 }
@@ -348,12 +365,12 @@ void SipAddressesModel::handlePresenceReceived (
   updateObservers(sipAddress, status);
 }
 
-void SipAddressesModel::handleAllEntriesRemoved (ChatModel *chatModel) {
-  auto it = mPeerAddressToSipAddressEntry.find(chatModel->getPeerAddress());
+void SipAddressesModel::handleAllEntriesRemoved (ChatRoomModel *chatRoomModel) {
+  auto it = mPeerAddressToSipAddressEntry.find(chatRoomModel->getPeerAddress());
   if (it == mPeerAddressToSipAddressEntry.end())
     return;
 
-  auto it2 = it->localAddressToConferenceEntry.find(Utils::cleanSipAddress(chatModel->getLocalAddress()));
+  auto it2 = it->localAddressToConferenceEntry.find(Utils::cleanSipAddress(chatRoomModel->getLocalAddress()));
   if (it2 == it->localAddressToConferenceEntry.end())
     return;
   it->localAddressToConferenceEntry.erase(it2);
@@ -370,22 +387,22 @@ void SipAddressesModel::handleAllEntriesRemoved (ChatModel *chatModel) {
   emit dataChanged(index(row, 0), index(row, 0));
 }
 
-void SipAddressesModel::handleLastEntryRemoved (ChatModel *chatModel) {
-  auto it = mPeerAddressToSipAddressEntry.find(chatModel->getPeerAddress());
+void SipAddressesModel::handleLastEntryRemoved (ChatRoomModel *chatRoomModel) {
+  auto it = mPeerAddressToSipAddressEntry.find(chatRoomModel->getPeerAddress());
   if (it == mPeerAddressToSipAddressEntry.end())
     return;
 
-  auto it2 = it->localAddressToConferenceEntry.find(Utils::cleanSipAddress(chatModel->getLocalAddress()));
+  auto it2 = it->localAddressToConferenceEntry.find(Utils::cleanSipAddress(chatRoomModel->getLocalAddress()));
   if (it2 == it->localAddressToConferenceEntry.end())
     return;
 
   int row = mRefs.indexOf(&(*it));
   Q_ASSERT(row != -1);
 
-  Q_ASSERT(chatModel->rowCount() > 0);
-  const QVariantMap map = chatModel->data(
-    chatModel->index(chatModel->rowCount() - 1, 0),
-    ChatModel::ChatEntry
+  Q_ASSERT(chatRoomModel->rowCount() > 0);
+  const QVariantMap map = chatRoomModel->data(
+    chatRoomModel->index(chatRoomModel->rowCount() - 1, 0),
+    ChatRoomModel::ChatEntry
   ).toMap();
 
   // Update the timestamp with the new last chat message timestamp.
@@ -402,13 +419,13 @@ void SipAddressesModel::handleAllCallCountReset () {
     emit dataChanged(index(row, 0), index(row, 0));
   }
 }
-void SipAddressesModel::handleMessageCountReset (ChatModel *chatModel) {
-  const QString &peerAddress = Utils::cleanSipAddress(chatModel->getPeerAddress());
+void SipAddressesModel::handleMessageCountReset (ChatRoomModel *chatRoomModel) {
+  const QString &peerAddress = Utils::cleanSipAddress(chatRoomModel->getPeerAddress());
   auto it = mPeerAddressToSipAddressEntry.find(peerAddress);
   if (it == mPeerAddressToSipAddressEntry.end())
     return;
 
-  const QString &localAddress = Utils::cleanSipAddress(chatModel->getLocalAddress());
+  const QString &localAddress = Utils::cleanSipAddress(chatRoomModel->getLocalAddress());
   auto it2 = it->localAddressToConferenceEntry.find(localAddress);
   if (it2 == it->localAddressToConferenceEntry.end())
     return;
@@ -424,7 +441,6 @@ void SipAddressesModel::handleMessageCountReset (ChatModel *chatModel) {
 }
 
 void SipAddressesModel::handleMessageSent (const shared_ptr<linphone::ChatMessage> &message) {
-  qInfo() << "Handle message sent.";
   const QString peerAddress(Utils::coreStringToAppString(message->getChatRoom()->getPeerAddress()->asStringUriOnly()));
   addOrUpdateSipAddress(peerAddress, message);
 }
@@ -515,6 +531,7 @@ void SipAddressesModel::addOrUpdateSipAddress (const QString &sipAddress, T data
   mRefs << &mPeerAddressToSipAddressEntry[sipAddress];
 
   endInsertRows();
+  emit layoutChanged();
 }
 
 // -----------------------------------------------------------------------------
@@ -549,24 +566,26 @@ void SipAddressesModel::removeContactOfSipAddress (const QString &sipAddress) {
 // -----------------------------------------------------------------------------
 
 void SipAddressesModel::initSipAddresses () {
-  QElapsedTimer timer;
-  timer.start();
+	QElapsedTimer timer, stepsTimer;
+	timer.start();
 
-  initSipAddressesFromChat();
-  initSipAddressesFromCalls();
-  initRefs();
-  initSipAddressesFromContacts();
-
-  qInfo() << "Sip addresses model initialized in:" << timer.elapsed() << "ms.";
+	stepsTimer.start();
+	initSipAddressesFromChat();
+	qInfo() << "Sip addresses model from Chats :" << stepsTimer.restart() << "ms.";
+	initSipAddressesFromCalls();
+	qInfo() << "Sip addresses model from Calls :" << stepsTimer.restart() << "ms.";
+	initRefs();
+	qInfo() << "Sip addresses model from Refs :" << stepsTimer.restart() << "ms.";
+	initSipAddressesFromContacts();
+	qInfo() << "Sip addresses model from Contacts :" << stepsTimer.restart() << "ms.";
+	qInfo() << "Sip addresses model initialized in:" << timer.elapsed() << "ms.";
 }
 
 void SipAddressesModel::initSipAddressesFromChat () {
-  
   for (const auto &chatRoom : CoreManager::getInstance()->getCore()->getChatRooms()) {
-    list<shared_ptr<linphone::ChatMessage>> history(chatRoom->getHistory(1));
-    if (history.empty())
-      continue;
-
+		auto lastMessage = chatRoom->getLastMessageInHistory();
+		if( !lastMessage)
+			continue;
     QString peerAddress(Utils::cleanSipAddress(Utils::coreStringToAppString(chatRoom->getPeerAddress()->asStringUriOnly())));
     QString localAddress(Utils::cleanSipAddress(Utils::coreStringToAppString(chatRoom->getLocalAddress()->asStringUriOnly())));
 
@@ -574,7 +593,7 @@ void SipAddressesModel::initSipAddressesFromChat () {
       chatRoom->getUnreadMessagesCount(),
       CoreManager::getInstance()->getMissedCallCount(peerAddress, localAddress),
       false,
-      QDateTime::fromMSecsSinceEpoch(history.back()->getTime() * 1000)
+      QDateTime::fromMSecsSinceEpoch(lastMessage->getTime() * 1000)
     };
   }
 }
