@@ -25,11 +25,13 @@
 #include <QImageReader>
 #include <QDebug>
 
+#include "config.h"
 #include "Utils.hpp"
 #include "components/core/CoreManager.hpp"
 #include "components/contacts/ContactsListModel.hpp"
 #include "components/contact/ContactModel.hpp"
 #include "components/contact/VcardModel.hpp"
+#include "components/settings/SettingsModel.hpp"
 #include "app/paths/Paths.hpp"
 
 // =============================================================================
@@ -493,16 +495,21 @@ QString Utils::getDisplayName(const std::shared_ptr<const linphone::Address>& ad
 		if(model && model->getVcardModel())
 			displayName = model->getVcardModel()->getUsername();
 		else{
-			auto callHistory = CoreManager::getInstance()->getCore()->getCallLogs();
-			auto callLog = std::find_if(callHistory.begin(), callHistory.end(), [address](std::shared_ptr<linphone::CallLog>& cl){
-					return cl->getRemoteAddress()->weakEqual(address);
-		});
-			if(callLog != callHistory.end())
-				displayName = QString::fromStdString((*callLog)->getRemoteAddress()->getDisplayName());
-			if(displayName == "")
-				displayName = QString::fromStdString(address->getDisplayName());
-			if(displayName == "")
-				displayName = Utils::coreStringToAppString(address->getUsername());
+			// Try to get display from full address
+			displayName = QString::fromStdString(address->getDisplayName());
+			if( displayName == ""){
+				// Try to get display name from logs
+				auto callHistory = CoreManager::getInstance()->getCore()->getCallLogs();
+				auto callLog = std::find_if(callHistory.begin(), callHistory.end(), [address](std::shared_ptr<linphone::CallLog>& cl){
+						return cl->getRemoteAddress()->weakEqual(address);
+				});
+				if(callLog != callHistory.end())
+					displayName = QString::fromStdString((*callLog)->getRemoteAddress()->getDisplayName());
+				if(displayName == "")
+					displayName = QString::fromStdString(address->getDisplayName());
+				if(displayName == "")
+					displayName = Utils::coreStringToAppString(address->getUsername());
+			}
 		}
 	}
 	return displayName;
@@ -514,4 +521,12 @@ std::shared_ptr<linphone::Config> Utils::getConfigIfExists (const QString &confi
 		factoryPath.clear();
 	
 	return linphone::Config::newWithFactory(configPath.toStdString(), factoryPath);
+}
+
+QString Utils::computeUserAgent(const std::shared_ptr<linphone::Config>& config){
+	return QStringLiteral(APPLICATION_NAME" Desktop/%1 (%2) %3, Qt %4 LinphoneCore")
+					.arg(QCoreApplication::applicationVersion())
+					.arg(SettingsModel::getDeviceName(config))
+					.arg(QSysInfo::prettyProductName())
+					.arg(qVersion());
 }
\ No newline at end of file
